==> eiffelstudio-18.01.10.1424.tar: F_code/C8/in391.c <==
/*
 * Code for class INTERNAL
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in391.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INTERNAL}.is_instance_of */
EIF_BOOLEAN F655_6434 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("is_instance_of", 654, Current, 0, 2, 6756);
	RTGC;
	RTHOOK(1);
	tr1 = RTCCL(arg1);
	ti4_1 = F655_6442(Current, tr1);
	Result = F654_6401(Current, ti4_1, arg2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {INTERNAL}.class_name */
EIF_REFERENCE F655_6440 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	
	
	RTEAA("class_name", 654, Current, 0, 1, 6762);
	RTHOOK(1);
	tr1 = (EIF_REFERENCE) eif_builtin_ANY_generator (arg1);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) tr1;
}

/* {INTERNAL}.dynamic_type */
EIF_INTEGER_32 F655_6442 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("dynamic_type", 654, Current, 0, 1, 6764);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(6494,F655_6494,(Current));
	tr2 = RTCCL(arg1);
	F683_6714(RTCW(tr1), tr2);
	RTHOOK(2);
	Result = *(EIF_INTEGER_32 *)(RTCV(RTOSCF(6494,F655_6494,(Current)))+ _LNGOFF_1_0_0_0_);
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {INTERNAL}.reflected_object */
static EIF_REFERENCE F655_6494_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("reflected_object", 654, Current, 0, 0, 6816);
	RTGC;
	RTOSP (6494);
#define Result RTOSR(6494)
	RTOC_NEW(Result);
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(682, 0x00).id, 682, _OBJSIZ_1_0_0_2_0_0_0_0_);
	F683_6705(RTCW(tr1), Current);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (6494);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F655_6494 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6494,F655_6494_body,(Current));
}

void EIF_Minit391 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C8/in391.c <==
/*
 * Code for class INTERNAL
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in391.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INTERNAL}.is_instance_of */
EIF_BOOLEAN F655_6434 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("is_instance_of", 654, Current, 0, 2, 6756);
	RTGC;
	RTHOOK(1);
	tr1 = RTCCL(arg1);
	ti4_1 = F655_6442(Current, tr1);
	Result = F654_6401(Current, ti4_1, arg2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {INTERNAL}.class_name */
EIF_REFERENCE F655_6440 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	
	
	RTEAA("class_name", 654, Current, 0, 1, 6762);
	RTHOOK(1);
	tr1 = (EIF_REFERENCE) eif_builtin_ANY_generator (arg1);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) tr1;
}

/* {INTERNAL}.dynamic_type */
EIF_INTEGER_32 F655_6442 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("dynamic_type", 654, Current, 0, 1, 6764);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(6494,F655_6494,(Current));
	tr2 = RTCCL(arg1);
	F683_6714(RTCW(tr1), tr2);
	RTHOOK(2);
	Result = *(EIF_INTEGER_32 *)(RTCV(RTOSCF(6494,F655_6494,(Current)))+ _LNGOFF_1_0_0_0_);
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {INTERNAL}.reflected_object */
static EIF_REFERENCE F655_6494_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("reflected_object", 654, Current, 0, 0, 6816);
	RTGC;
	RTOSP (6494);
#define Result RTOSR(6494)
	RTOC_NEW(Result);
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(682, 0x00).id, 682, _OBJSIZ_1_0_0_2_0_0_0_0_);
	tr2 = RTMS_EX_H("",0,0);
	F683_6705(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (6494);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F655_6494 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6494,F655_6494_body,(Current));
}

void EIF_Minit391 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
